@@ -6,8 +6,9 @@
 #include "loadnoteitemsworker.h"
 #include "db/vnoteitemoper.h"
 #include "globaldef.h"
+#include <QDebug>
 
-#include <DLog>
+// #include <DLog>
 
 #include <QThread>
 
