@@ -4,7 +4,7 @@
 <context>
     <name>AppMain</name>
     <message>
-        <location filename="../src/common/vlcplayer.cpp" line="85"/>
+        <location filename="../src/common/vlcplayer.cpp" line="87"/>
         <source>Voice Notes</source>
         <translation>Puhemuistio</translation>
     </message>
@@ -12,7 +12,7 @@
 <context>
     <name>DefaultName</name>
     <message>
-        <location filename="../src/db/vnotefolderoper.cpp" line="226"/>
+        <location filename="../src/db/vnotefolderoper.cpp" line="249"/>
         <source>Notebook</source>
         <translation>Muistikirja</translation>
     </message>
@@ -22,9 +22,9 @@
         <translation>Puhe</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="214"/>
+        <location filename="../src/db/vnoteitemoper.cpp" line="226"/>
         <source>Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Teksti</translation>
     </message>
 </context>
 <context>
@@ -42,7 +42,7 @@
     <message>
         <location filename="../src/gui/mainwindow/FolderListView.qml" line="545"/>
         <source>New Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Uusi huomautus</translation>
     </message>
 </context>
 <context>
@@ -50,7 +50,7 @@
     <message>
         <location filename="../src/gui/mainwindow/InitialInterface.qml" line="66"/>
         <source>After creating a new notepad, you can start recording voice and text</source>
-        <translation type="unfinished"></translation>
+        <translation>Luoessa uuden huomautusmerkintätyökalun voit aloittaa äänen ja tekstin tallennuksen</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/InitialInterface.qml" line="73"/>
@@ -61,44 +61,42 @@
 <context>
     <name>ItemListView</name>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="78"/>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="80"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
         <source>move </source>
-        <translation type="unfinished"></translation>
+        <translation>siirrä </translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="78"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="79"/>
         <source> notes to :</source>
-        <translation type="unfinished"></translation>
+        <translation> huomautuksia : </translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="80"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="81"/>
         <source> note to :</source>
-        <translation type="unfinished"></translation>
+        <translation> huomautusta : </translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="163"/>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="190"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="160"/>
         <source>Save As</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna nimellä</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="228"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="279"/>
         <source>No search results</source>
         <translation type="unfinished">Ei hakutuloksia</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="244"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
         <source>Unpin</source>
-        <translation type="unfinished"></translation>
+        <translation>Poista kiinni</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="244"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="295"/>
         <source>Sticky on Top</source>
         <translation type="unfinished">Päälimmäinen</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/ItemListView.qml" line="690"/>
+        <location filename="../src/gui/mainwindow/ItemListView.qml" line="752"/>
         <source>Sticky Notes</source>
         <translation type="unfinished">Muistilaput</translation>
     </message>
@@ -106,12 +104,12 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/gui/mainwindow/MainWindow.qml" line="381"/>
+        <location filename="../src/gui/mainwindow/MainWindow.qml" line="370"/>
         <source>Create Notebook</source>
         <translation type="unfinished">Luo muistikirja</translation>
     </message>
     <message>
-        <location filename="../src/gui/mainwindow/MainWindow.qml" line="534"/>
+        <location filename="../src/gui/mainwindow/MainWindow.qml" line="523"/>
         <source>Search</source>
         <translation type="unfinished">Etsi</translation>
     </message>
@@ -121,17 +119,17 @@
     <message>
         <location filename="../src/gui/dialog/MoveDialog.qml" line="24"/>
         <source>Move Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Siirrä huomautusta</translation>
     </message>
     <message>
-        <location filename="../src/gui/dialog/MoveDialog.qml" line="127"/>
+        <location filename="../src/gui/dialog/MoveDialog.qml" line="136"/>
         <source>Cancel</source>
         <translation type="unfinished">Peru</translation>
     </message>
     <message>
-        <location filename="../src/gui/dialog/MoveDialog.qml" line="144"/>
+        <location filename="../src/gui/dialog/MoveDialog.qml" line="153"/>
         <source>Ok</source>
-        <translation type="unfinished"></translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
@@ -139,7 +137,7 @@
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="37"/>
         <source>%1 note selected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 huomautusta valittu</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="56"/>
@@ -149,12 +147,12 @@
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="69"/>
         <source>Save Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna huomautus</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="82"/>
         <source>Save Voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna ääni</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/MultipleChoices.qml" line="93"/>
@@ -165,90 +163,80 @@
 <context>
     <name>NoteDetailContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="68"/>
+        <location filename="../src/common/actionmanager.cpp" line="69"/>
         <source>Save as MP3</source>
         <translation>Tallenna MP3</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="69"/>
+        <location filename="../src/common/actionmanager.cpp" line="70"/>
         <source>Voice to Text</source>
         <translation>Puhe tekstiksi</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="70"/>
-        <location filename="../src/common/actionmanager.cpp" line="78"/>
-        <location filename="../src/common/actionmanager.cpp" line="86"/>
+        <location filename="../src/common/actionmanager.cpp" line="71"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="71"/>
-        <location filename="../src/common/actionmanager.cpp" line="79"/>
-        <location filename="../src/common/actionmanager.cpp" line="87"/>
+        <location filename="../src/common/actionmanager.cpp" line="72"/>
         <source>Select all</source>
-        <translation type="unfinished"></translation>
+        <translation>Valitse kaikki</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="72"/>
-        <location filename="../src/common/actionmanager.cpp" line="80"/>
-        <location filename="../src/common/actionmanager.cpp" line="88"/>
+        <location filename="../src/common/actionmanager.cpp" line="73"/>
         <source>Copy</source>
         <translation>Kopioi</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="73"/>
-        <location filename="../src/common/actionmanager.cpp" line="81"/>
-        <location filename="../src/common/actionmanager.cpp" line="89"/>
+        <location filename="../src/common/actionmanager.cpp" line="74"/>
         <source>Cut</source>
         <translation>Leikkaa</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="74"/>
-        <location filename="../src/common/actionmanager.cpp" line="82"/>
-        <location filename="../src/common/actionmanager.cpp" line="90"/>
+        <location filename="../src/common/actionmanager.cpp" line="75"/>
         <source>Paste</source>
         <translation>Liitä</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="77"/>
+        <location filename="../src/common/actionmanager.cpp" line="78"/>
         <source>View</source>
         <translation>Näytä</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="83"/>
+        <location filename="../src/common/actionmanager.cpp" line="84"/>
         <source>Save as</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="92"/>
-        <source>Text to Speech</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna nimellä</translation>
     </message>
     <message>
         <location filename="../src/common/actionmanager.cpp" line="93"/>
-        <source>Stop reading</source>
-        <translation type="unfinished"></translation>
+        <source>Text to Speech</source>
+        <translation>Teksti ääneksi</translation>
     </message>
     <message>
         <location filename="../src/common/actionmanager.cpp" line="94"/>
+        <source>Stop reading</source>
+        <translation>Pysäytä lukeminen</translation>
+    </message>
+    <message>
+        <location filename="../src/common/actionmanager.cpp" line="95"/>
         <source>Speech to Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Ääni tekstimuotoon</translation>
     </message>
 </context>
 <context>
     <name>NotebookContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="46"/>
+        <location filename="../src/common/actionmanager.cpp" line="47"/>
         <source>Rename</source>
         <translation>Nimeä</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="47"/>
+        <location filename="../src/common/actionmanager.cpp" line="48"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="48"/>
+        <location filename="../src/common/actionmanager.cpp" line="49"/>
         <source>New note</source>
         <translation type="unfinished">Uusi muistiinpano</translation>
     </message>
@@ -256,47 +244,47 @@
 <context>
     <name>NotesContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="62"/>
+        <location filename="../src/common/actionmanager.cpp" line="63"/>
         <source>Save as HTML</source>
         <translation>Tallenna HTML</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="63"/>
+        <location filename="../src/common/actionmanager.cpp" line="64"/>
         <source>Save as TXT</source>
         <translation>Tallenna muodossa TXT</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="56"/>
+        <location filename="../src/common/actionmanager.cpp" line="57"/>
         <source>Save note</source>
         <translation>Tallenna muistiinpano</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="51"/>
+        <location filename="../src/common/actionmanager.cpp" line="52"/>
         <source>Rename</source>
         <translation>Nimeä</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="53"/>
+        <location filename="../src/common/actionmanager.cpp" line="54"/>
         <source>Move</source>
         <translation>Siirrä</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="54"/>
+        <location filename="../src/common/actionmanager.cpp" line="55"/>
         <source>Delete</source>
         <translation>Poista</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="57"/>
+        <location filename="../src/common/actionmanager.cpp" line="58"/>
         <source>Save voice recording</source>
         <translation>Tallenna puhe</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="59"/>
+        <location filename="../src/common/actionmanager.cpp" line="60"/>
         <source>New note</source>
         <translation>Uusi muistiinpano</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="52"/>
+        <location filename="../src/common/actionmanager.cpp" line="53"/>
         <source>Sticky on Top</source>
         <translation>Päälimmäinen</translation>
     </message>
@@ -304,25 +292,24 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="230"/>
-        <source>Please install &apos;UOS AI&apos; from the App Store before using</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="261"/>
+        <source>Please install 'UOS AI' from the App Store before using</source>
+        <translation>Asenna 'UOS AI' App Storesta ennen käyttöä</translation>
     </message>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="232"/>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="263"/>
         <source>No audio input device detected. Please check and try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänensisäänmenettävää laitetta ei havaittu. Tarkista ja yritä uudelleen</translation>
     </message>
     <message>
-        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="234"/>
+        <location filename="../src/common/vtextspeechandtrmanager.cpp" line="265"/>
         <source>No audio output device detected. Please check and try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänenvahvistimen laitetta ei havaittu. Tarkista ja yritä uudelleen</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="56"/>
-        <location filename="../src/main.cpp" line="57"/>
+        <location filename="../src/main.cpp" line="99"/>
         <source>deepin-voice-note</source>
-        <translation type="unfinished"></translation>
+        <translation>deepin-voice-note</translation>
     </message>
 </context>
 <context>
@@ -374,120 +361,120 @@
 <context>
     <name>Shortcuts</name>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="742"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="804"/>
         <source>New notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Uusi vihje</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="743"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="805"/>
         <source>Rename notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Muuta vihjen nimeä</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="744"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="806"/>
         <source>Delete notebook</source>
-        <translation type="unfinished"></translation>
+        <translation>Poista vihje</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="766"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="828"/>
         <source>New note</source>
         <translation type="unfinished">Uusi muistiinpano</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="767"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="829"/>
         <source>Rename note</source>
-        <translation type="unfinished"></translation>
+        <translation>Muuta huomautuksen nimeä</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="768"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="830"/>
         <source>Delete note</source>
-        <translation type="unfinished"></translation>
+        <translation>Poista huomautus</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="769"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="831"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"></translation>
+        <translation>Peli/Pysäytä</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="770"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="832"/>
         <source>Record voice</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna ääntä</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="771"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="833"/>
         <source>Save note</source>
         <translation type="unfinished">Tallenna muistiinpano</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="772"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="834"/>
         <source>Save recordings</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna tallennuksia</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="792"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="854"/>
         <source>Select all</source>
-        <translation type="unfinished"></translation>
+        <translation>Valitse kaikki</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="793"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="855"/>
         <source>Copy</source>
         <translation type="unfinished">Kopioi</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="794"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="856"/>
         <source>Cut</source>
         <translation type="unfinished">Leikkaa</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="795"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="857"/>
         <source>Paste</source>
         <translation type="unfinished">Liitä</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="796"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="858"/>
         <source>Undo</source>
-        <translation type="unfinished"></translation>
+        <translation>Takaisin</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="797"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="859"/>
         <source>Redo</source>
-        <translation type="unfinished"></translation>
+        <translation>Uudelleen</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="798"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="860"/>
         <source>Delete</source>
         <translation type="unfinished">Poista</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="821"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="883"/>
         <source>Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Apua</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="822"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="884"/>
         <source>Display shortcuts</source>
-        <translation type="unfinished"></translation>
+        <translation>Näytä pikanäppäimet</translation>
     </message>
 </context>
 <context>
     <name>ShortcutsGroups</name>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="748"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="810"/>
         <source>Notebooks</source>
-        <translation type="unfinished"></translation>
+        <translation>Kirjanpito</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="776"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="838"/>
         <source>Notes</source>
-        <translation type="unfinished"></translation>
+        <translation>Huomionkäynnit</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="802"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="864"/>
         <source>Edit</source>
-        <translation type="unfinished"></translation>
+        <translation>Muokkaa</translation>
     </message>
     <message>
-        <location filename="../src/common/VNoteMainManager.cpp" line="826"/>
+        <location filename="../src/common/VNoteMainManager.cpp" line="888"/>
         <source>Settings</source>
         <translation type="unfinished">Asetukset</translation>
     </message>
@@ -502,17 +489,17 @@
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="30"/>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation>Yksityisyyspolitiikka</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="53"/>
         <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
-        <translation type="unfinished"></translation>
+        <translation>Voice Notes on kevyt muisti kirjanpito, jolla voidaan tehdä tekstihuomioita ja äänirekisteröintiä.</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/TitleBarMenu.qml" line="55"/>
         <source>Voice Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänihuomio</translation>
     </message>
 </context>
 <context>
@@ -526,27 +513,110 @@
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/common/utils.cpp" line="42"/>
+        <location filename="../src/common/utils.cpp" line="46"/>
         <source>1 min ago</source>
         <translation>1 minuutti sitten</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="44"/>
+        <location filename="../src/common/utils.cpp" line="48"/>
         <source>%1 mins ago</source>
         <translation>%1 minuuttia sitten</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="50"/>
+        <location filename="../src/common/utils.cpp" line="56"/>
         <source>Yesterday</source>
         <translation>Eilen</translation>
     </message>
+    <message>
+        <location filename="../tests/src/common/ut_utils.cpp" line="33"/>
+        <source>2 mins ago</source>
+        <translation>Kaksi minuuttia sitten</translation>
+    </message>
+</context>
+<context>
+    <name>VNoteMessageDialog</name>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="28"/>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="39"/>
+        <source>Are you sure you want to delete this notebook?
+All notes in it will be deleted</source>
+        <translation>Oletko varma, että haluat poistaa tämän kirjanpidon?
+Kaikki huomionkäynnit siitä poistetaan</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
+        <source>Do you want to stop the current recording?</source>
+        <translation type="unfinished">Haluatko lopettaa nykyisen tallennuksen?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="52"/>
+        <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
+        <translation type="unfinished">Tätä tallennetta ei voi muuntaa, koska yli 20 minuutin muistiinpanoja ei tueta tällä hetkellä.</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
+        <source>Converting a voice note now. Do you want to stop it?</source>
+        <translation type="unfinished">Puhetta muunnetaan nyt. Haluatko pysäyttää sen?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="65"/>
+        <source>The low input volume may result in bad recordings. Do you want to continue?</source>
+        <translation type="unfinished">Alhainen äänenvoimakkuus voi johtaa huonoon äänenlaatuun. Haluatko jatkaa?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
+        <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
+        <translation type="unfinished">Leikatut tallenteet ja muunnettua tekstiä ei liitetä. Haluatko jatkaa?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="81"/>
+        <source>Are you sure you want to delete this note?</source>
+        <translation type="unfinished">Haluatko varmasti poistaa tämän merkinnän?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="87"/>
+        <source>Are you sure you want to delete the selected %1 notes?</source>
+        <translation type="unfinished">Haluatko varmasti poistaa %1 merkintää?</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation type="unfinished">Peru</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="98"/>
+        <source>Confirm</source>
+        <comment>button</comment>
+        <translation type="unfinished">Vahvista</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="106"/>
+        <source>Save failed</source>
+        <translation type="unfinished">Tallennus epäonnistui</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="111"/>
+        <source>You do not have permission to save files there</source>
+        <translation type="unfinished">Sinulla ei ole oikeuksia sinne tallentaa tiedostoja</translation>
+    </message>
+    <message>
+        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="116"/>
+        <source>The voice note has been deleted</source>
+        <translation type="unfinished">Puhemuistio on poistettu</translation>
+    </message>
 </context>
 <context>
     <name>VNoteMessageDialogHandler</name>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="97"/>
         <source>Are you sure you want to delete this notebook?</source>
-        <translation type="unfinished"></translation>
+        <translation>Oletko varma, että haluat poistaa tämän kirjanpidon?</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="99"/>
@@ -601,12 +671,12 @@
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="129"/>
         <source>The voice conversion failed due to the poor network connection, please have a check</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänimuunnos epäonnistui heikosta verkkoyhteydestä, tarkista verkkoyhteys</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="141"/>
         <source>All notes in it will be deleted</source>
-        <translation type="unfinished"></translation>
+        <translation>Kaikki huomionkäynnit siitä poistetaan</translation>
     </message>
     <message>
         <location filename="../src/handler/vnote_message_dialog_handler.cpp" line="154"/>
@@ -630,9 +700,9 @@
 <context>
     <name>WebEngineHandler</name>
     <message>
-        <location filename="../src/handler/web_engine_handler.cpp" line="483"/>
+        <location filename="../src/handler/web_engine_handler.cpp" line="647"/>
         <source>save as MP3</source>
-        <translation type="unfinished"></translation>
+        <translation>Tallenna MP3-muodossa</translation>
     </message>
 </context>
 <context>
@@ -640,95 +710,95 @@
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="60"/>
         <source>Create Note</source>
-        <translation type="unfinished"></translation>
+        <translation>Luo huomio</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
         <source>Start recording</source>
-        <translation type="unfinished"></translation>
+        <translation>Aloita tallennus</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="100"/>
         <source>No recording device detected</source>
-        <translation type="unfinished"></translation>
+        <translation>Äänitallennuslaite ei ole havaittu</translation>
     </message>
     <message>
         <location filename="../src/gui/mainwindow/WindowTitleBar.qml" line="119"/>
         <source>Insert picture</source>
-        <translation type="unfinished"></translation>
+        <translation>Lisää kuva</translation>
     </message>
 </context>
 <context>
     <name>web</name>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="131"/>
+        <location filename="../src/common/jscontent.cpp" line="146"/>
         <source>Font</source>
         <translation>Fontti</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="132"/>
+        <location filename="../src/common/jscontent.cpp" line="147"/>
         <source>Font size</source>
         <translation>Fontin koko</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="133"/>
+        <location filename="../src/common/jscontent.cpp" line="148"/>
         <source>Font color</source>
         <translation>Fontin väri</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="134"/>
+        <location filename="../src/common/jscontent.cpp" line="149"/>
         <source>Text highlight color</source>
         <translation>Tekstin korostusväri</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="135"/>
+        <location filename="../src/common/jscontent.cpp" line="150"/>
         <source>Bold</source>
         <translation>Lihavoitu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="136"/>
+        <location filename="../src/common/jscontent.cpp" line="151"/>
         <source>Italic</source>
         <translation>Kursivoitu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="137"/>
+        <location filename="../src/common/jscontent.cpp" line="152"/>
         <source>Underline</source>
         <translation>Alleviivattu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="138"/>
+        <location filename="../src/common/jscontent.cpp" line="153"/>
         <source>Strikethrough</source>
         <translation>Yliviivattu</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="139"/>
+        <location filename="../src/common/jscontent.cpp" line="154"/>
         <source>Bullets</source>
         <translation>Pisteet</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="140"/>
+        <location filename="../src/common/jscontent.cpp" line="155"/>
         <source>Numbering</source>
         <translation>Numerointi</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="141"/>
+        <location filename="../src/common/jscontent.cpp" line="156"/>
         <source>More colors</source>
         <translation>Lisää värejä</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="142"/>
+        <location filename="../src/common/jscontent.cpp" line="157"/>
         <source>Recent</source>
         <translation>Uusin</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="156"/>
+        <location filename="../src/common/jscontent.cpp" line="173"/>
         <source>Voice To Text</source>
-        <translation type="unfinished"></translation>
+        <translation>Ääni tekstinä</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="157"/>
+        <location filename="../src/common/jscontent.cpp" line="174"/>
         <source>Converting voice to text</source>
-        <translation type="unfinished"></translation>
+        <translation>Muunnamme ääntä tekstinä</translation>
     </message>
 </context>
 </TS>
